from thumbny.commands.create import CreateCommand
from thumbny.commands.delete import DeleteCommand
from thumbny.commands.generate import GenerateCommand
from thumbny.commands.templates import TemplatesCommand
from thumbny.commands.info import InfoCommand

__all__ = [
    "CreateCommand",
    "DeleteCommand",
    "GenerateCommand",
    "InfoCommand",
    "TemplatesCommand",
]
