

class TemplateExist(Exception):
    ...


class TemplateNotExist(Exception):
    ...


class FontNotFound(Exception):
    ...


class NotValidFontExtension(Exception):
    ...


class NotAbleToCreate(Exception):
    ...
